==> cupy-10.0.0rc1.tar.gz: cupy-10.0.0rc1/cupyx/jit/__init__.py <==
from cupyx.jit._interface import rawkernel  # NOQA

from cupyx.jit._interface import threadIdx  # NOQA
from cupyx.jit._interface import blockDim  # NOQA
from cupyx.jit._interface import blockIdx  # NOQA
from cupyx.jit._interface import gridDim  # NOQA
from cupyx.jit._interface import warpsize  # NOQA

from cupyx.jit._builtin_funcs import syncthreads  # NOQA
from cupyx.jit._builtin_funcs import syncwarp  # NOQA
from cupyx.jit._builtin_funcs import shared_memory  # NOQA
from cupyx.jit._builtin_funcs import atomic_add  # NOQA
from cupyx.jit._builtin_funcs import atomic_sub  # NOQA
from cupyx.jit._builtin_funcs import atomic_exch  # NOQA
from cupyx.jit._builtin_funcs import atomic_min  # NOQA
from cupyx.jit._builtin_funcs import atomic_max  # NOQA
from cupyx.jit._builtin_funcs import atomic_inc  # NOQA
from cupyx.jit._builtin_funcs import atomic_dec  # NOQA
from cupyx.jit._builtin_funcs import atomic_cas  # NOQA
from cupyx.jit._builtin_funcs import atomic_and  # NOQA
from cupyx.jit._builtin_funcs import atomic_or  # NOQA
from cupyx.jit._builtin_funcs import atomic_xor  # NOQA
from cupyx.jit._builtin_funcs import grid  # NOQA
from cupyx.jit._builtin_funcs import gridsize  # NOQA
from cupyx.jit._builtin_funcs import laneid  # NOQA
from cupyx.jit._builtin_funcs import shfl_sync  # NOQA
from cupyx.jit._builtin_funcs import shfl_up_sync  # NOQA
from cupyx.jit._builtin_funcs import shfl_down_sync  # NOQA
from cupyx.jit._builtin_funcs import shfl_xor_sync  # NOQA

import inspect as _inspect

_getsource_func = _inspect.getsource  # NOQA

==> cupy-11.0.0rc1.tar.gz: cupy-11.0.0rc1/cupyx/jit/__init__.py <==
from cupyx.jit._interface import rawkernel  # NOQA

from cupyx.jit._interface import threadIdx  # NOQA
from cupyx.jit._interface import blockDim  # NOQA
from cupyx.jit._interface import blockIdx  # NOQA
from cupyx.jit._interface import gridDim  # NOQA
from cupyx.jit._interface import warpsize  # NOQA

from cupyx.jit._builtin_funcs import range_ as range  # NOQA
from cupyx.jit._builtin_funcs import syncthreads  # NOQA
from cupyx.jit._builtin_funcs import syncwarp  # NOQA
from cupyx.jit._builtin_funcs import shared_memory  # NOQA
from cupyx.jit._builtin_funcs import atomic_add  # NOQA
from cupyx.jit._builtin_funcs import atomic_sub  # NOQA
from cupyx.jit._builtin_funcs import atomic_exch  # NOQA
from cupyx.jit._builtin_funcs import atomic_min  # NOQA
from cupyx.jit._builtin_funcs import atomic_max  # NOQA
from cupyx.jit._builtin_funcs import atomic_inc  # NOQA
from cupyx.jit._builtin_funcs import atomic_dec  # NOQA
from cupyx.jit._builtin_funcs import atomic_cas  # NOQA
from cupyx.jit._builtin_funcs import atomic_and  # NOQA
from cupyx.jit._builtin_funcs import atomic_or  # NOQA
from cupyx.jit._builtin_funcs import atomic_xor  # NOQA
from cupyx.jit._builtin_funcs import grid  # NOQA
from cupyx.jit._builtin_funcs import gridsize  # NOQA
from cupyx.jit._builtin_funcs import laneid  # NOQA
from cupyx.jit._builtin_funcs import shfl_sync  # NOQA
from cupyx.jit._builtin_funcs import shfl_up_sync  # NOQA
from cupyx.jit._builtin_funcs import shfl_down_sync  # NOQA
from cupyx.jit._builtin_funcs import shfl_xor_sync  # NOQA

from cupyx.jit import cg  # NOQA

_n_functions_upperlimit = 100
